# Example usage:
import time

from kubejobs.jobs import KubernetesJob, KueueQueue, create_pvc

env_vars = {
    "DATASET_DIR": "/data/",
    "MODEL_DIR": "/data/model/",
}

# unique id generated using time


unique_id = time.strftime("%Y%m%d%H%M%S")


job = KubernetesJob(
    name=f"gate-dev-{unique_id}",
    image="ghcr.io/antreasantoniou/gate:latest",
    kueue_queue_name=KueueQueue.INFORMATICS,
    command=["/bin/bash", "-c", "--"],
    args=["while true; do sleep 60; done;"],
    gpu_type="nvidia.com/gpu",
    gpu_product="NVIDIA-A100-SXM4-40GB",
    shm_size="900G",  # "200G" is the maximum value for shm_size
    gpu_limit=1,
    backoff_limit=4,
    storage_request="1000Gi",
    env_vars=env_vars,
)

job_yaml = job.generate_yaml()
print(job_yaml)
job.run()
